@@ -41,3 +41,24 @@ sub set_argument {
 
 1;
 
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Apache - definition module for Apache HTTP Server
+
+=head1 SEE ALSO
+
+L<Apache HTTP Server|http://httpd.apache.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
