@@ -13,7 +13,6 @@ sub initialize {
     $self->{defined}{ArchiveName}       =   'cmake';
     $self->{defined}{WebSite}           =   'http://www.cmake.org';
     $self->{defined}{VersionForm}       =   '\d\.\d\.\d{1,2}(\.\d)?';
-    $self->{defined}{Extension}         =   'tar.gz';
     $self->{defined}{DownloadSite}      =   'http://www.cmake.org/files/';
 
     $self->{defined}{VersionList}       =   \&set_versionlist;
@@ -71,3 +70,25 @@ sub set_url {
 }
 
 1;
+
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Cmake - definition module for Cmake
+
+=head1 SEE ALSO
+
+L<CMake|http://www.cmake.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
