@@ -72,3 +72,25 @@ sub set_url {
 }
 
 1;
+
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Python - definition module for Python Programming Language
+
+=head1 SEE ALSO
+
+L<Python Programming Language|http://www.python.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
