@@ -158,3 +158,25 @@ sub set_versionlist {
 }
 
 1;
+
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Vim - definition module for Vim
+
+=head1 SEE ALSO
+
+L<Vim|http://www.vim.org>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
