@@ -10,19 +10,16 @@ sub initialize {
     
     $self->SUPER::initialize;
     
-    $self->{defined}{ArchiveName}       =   'wget';
     $self->{defined}{WebSite}           =   'http://www.gnu.org/software/wget/';
-    $self->{defined}{VersionForm}       =   '\d{1,2}\.\d{1,2}(\.\d{1,2})?';
-    $self->{defined}{Extension}         =   'tar.gz';
+
     $self->{defined}{Dependencies}      =   [ 'libidn' ];
+
     $self->{defined}{DownloadSite}      =   'http://ftp.gnu.org/gnu/wget/';
+
+    $self->{defined}{ArchiveName}       =   'wget';
+    $self->{defined}{VersionForm}       =   '\d{1,2}\.\d{1,2}(\.\d{1,2})?';
     
     $self->{defined}{AdditionalArgument}=   \&set_argument;
-    
-    $self->{defined}{CommandConfigure}  =   './configure';
-    $self->{defined}{CommandMake}       =   'make';
-    $self->{defined}{CommandTest}       =   'make check';
-    $self->{defined}{CommandInstall}    =   'make install';
 
     return $self;
 }
@@ -42,3 +39,24 @@ sub set_argument {
 
 1;
 
+=pod
+
+=head1 NAME
+
+Enbld::Definition::Wget - definition module for GNU Wget
+
+=head1 SEE ALSO
+
+L<GNU Wget|http://www.gnu.org/software/wget/>
+L<Enbld::Definition>
+
+=head1 COPYRIGHT
+
+copyright 2013- Magnolia C<< <magnolia.k@me.com> >>.
+
+=head1 LICENSE
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
